# autoESDA


[![image](https://img.shields.io/pypi/v/autoesda.svg)](https://pypi.python.org/pypi/autoesda)
[![image](https://img.shields.io/conda/vn/conda-forge/autoesda.svg)](https://anaconda.org/conda-forge/autoesda)
[![image](https://github.com/NicholasDeKock/autoesda/workflows/docs/badge.svg)](https://autoesda.gishub.org)
[![image](https://github.com/NicholasDeKock/autoesda/workflows/build/badge.svg)](https://github.com/giswqs/autoesda/actions?query=workflow%3Abuild)
[![image](https://img.shields.io/pypi/l/autoesda?color=yellow&label=Licence&logo=BSD-3-Clause)](https://opensource.org/licenses/BSD-3-Clause)

**A Python package that automated the exploratory spatial data analysis (ESDA) process by summarising the results in an HTML report**


-   Free software: BSD-3-Clause license
-   Documentation: https://NicholasDeKock.github.io/autoesda
    

## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
